import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="slack-webhook-alpa", # Replace with your own username
    version="0.0.2",
    author="Albert Pang",
    author_email="alpaaccount@mac.com",
    description="Wrapper for slack_sdk",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/alpaalpa/slack-webhook",
    packages=setuptools.find_packages(),
    install_requires = [
        "slack_sdk"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
)



'''
Documentation for Slack Incoming Webhook:
    https://api.slack.com/messaging/webhooks
'''
from logging import getLogger
import requests

logger = getLogger(__name__)


class SlackWebhookException(Exception):
    def __init__(self, message):
        self.message = message

    def __str__(self):
        return self.message


class SlackWebhook():
    """Class for sending notification to Slack via Incoming Webhook

    Parameters
    ----------
    url : str
        URL generated by the Slack administor for the incoming-webhook app
    channel : str
        channel name (not supported by all URL/App, depending on how it's setup)
    username : str
        overwrite username on the message (not supported by all URL/App, depending
        on administrator setting)
    icon_emoji : str
        name of emoji as the avatar of the user. (not supported by all URL/App)
    """
    def __init__(self, url, channel=None, username=None,
                 icon_emoji=None):
        self._channel = channel
        self._url = url
        self._username = username
        self._icon_emoji = icon_emoji

    def send(self, text):
        """send a text message into the configured channel

        Parameters
        ----------
        text : str
            Text to be sent
        """
        payload = {
            'text': text
        }
        if self.channel:
            payload['channel'] = self.channel
        if self.username:
            payload['username'] = self.username
        if self.icon_emoji:
            payload['icon_emoji'] = self.icon_emoji

        try:
            r = requests.post(self.url, json=payload)
            if r.status_code == 404:
                raise SlackWebhookException('API call return 404 error')
            elif r.status_code != 200:
                raise SlackWebhookException(f'Abnormal status sode from API call: {r.status_code} ({r.text})')
        except SlackWebhookException as e:
            logger.error(e)

    @property
    def channel(self):
        return self._channel

    @property
    def url(self):
        return self._url

    @property
    def username(self):
        return self._username

    @property
    def icon_emoji(self):
        return self._icon_emoji
